"""Plonista installation methods

$Id: Install.py 51 2005-10-04 21:50:44Z tvon $
"""
import string

from cStringIO import StringIO

from Products.CMFCore.utils import getToolByName
from Products.CMFCore.DirectoryView import addDirectoryViews
from Products.CMFCore.CMFCorePermissions import ManagePortal

from Products.Plonista import skin_globals


skinFolders = ('Plonista',)
skinName = 'Plonista'
baseSkin = 'Plone Tableless'

stylesheets = (
        {'css': 'plonista.css', 'media': 'screen'},
        {'css': 'plonista-fullscreen.css', 'media': 'screen'},
        )

# Make sure we only get our CSS when we are using our skin.
stylesheetCondition = "python:request.get(here.portal_skins.getRequestVarname(), here.portal_skins.getDefaultSkin()) == '%s'" % skinName


def setupSkin(self, out):
    """Add Plonista skin if does not already exist."""
    skinsTool = getToolByName(self, 'portal_skins')
    
    addDirectoryViews(skinsTool, 'skins', skin_globals)
    print >> out, "Added directory views to portal_skins."
       
    if skinName not in skinsTool.getSkinSelections():
        path = skinsTool.getSkinPath(baseSkin)
        path = map(string.strip, string.split(path,','))
        
        for skinFolder in skinFolders:
            if skinFolder not in path:
                try: 
                    path.insert(path.index('custom') + 1, skinFolder)
                except ValueError:
                    path.append(skinFolder)
    
        path = string.join(path, ', ')    
        skinsTool.addSkinSelection(skinName, path)
    else:
        print >> out, 'Skin already exists, leaving it alone.'
  

def removeSkin(self, out):
    """Remove Plonista skin."""
    skinsTool = getToolByName(self, 'portal_skins')
    
    # Revert to 'Plone Default' if the current skin is the default
    if self.portal_skins.getDefaultSkin() == skinName:
        self.portal_skins.default_skin = 'Plone Default'

    # Delete the property which holds the skin
    if skinName in skinsTool.getSkinSelections():
        skinsTool.manage_skinLayers(del_skin = 1, chosen = (skinName,))


def registerStylesheets(self, out):
    """Register stylesheets with the css registry."""
    csstool = getToolByName(self, 'portal_css')

    for stylesheet in stylesheets:
        csstool.registerStylesheet(
                stylesheet['css'],
                media=stylesheet['media'],
                expression=stylesheetCondition,
                rendering='import')

    print >> out, "Registered Plonista stylesheets."


def unregisterStylesheets(self, out):
    """Remove registration of stylesheets from the css registry."""
    csstool = getToolByName(self, 'portal_css')

    for stylesheet in stylesheets:
        csstool.unregisterResource(stylesheet['css'])

    print >> out, "Remove registeration of Plonista stylesheets."


def install(self):
    """Install Plonista skin and registered css."""
    out = StringIO()
    setupSkin(self, out)
    registerStylesheets(self, out)
    print >> out, 'Installation completed.'
    return out.getvalue()


def uninstall(self):
    """Un-install Plonista skin and registered css."""
    out = StringIO()
    unregisterStylesheets(self, out)
    removeSkin(self, out)

    print >> out, 'Un-installation completed.'
    return out.getvalue()
